==================
django-lbutils
==================

.. image:: https://secure.travis-ci.org/vicalloy/lbutils.svg?branch=master
   :target: http://travis-ci.org/vicalloy/lbutils

.. image:: https://coveralls.io/repos/github/vicalloy/lbutils/badge.svg?branch=master
   :target: https://coveralls.io/github/vicalloy/lbutils?branch=master

.. image:: https://img.shields.io/pypi/v/django-lbutils.svg
   :target: https://pypi.python.org/pypi/django-lbutils/
   :alt: Latest PyPI version

.. image:: https://img.shields.io/pypi/dm/django-lbutils.svg
   :target: https://pypi.python.org/pypi/django-lbutils/
   :alt: Number of PyPI downloads

A set of useful utils for Django.

``django-lbutils`` supports `Django`_ 1.6.0 and later on Python 2.7,
3.2, 3.3 and 3.4.

.. _Django: http://www.djangoproject.com/


Getting Help
============

Documentation for django-lbutils is available at https://django-lbutils.readthedocs.org/


Contributing
============

Please file bugs and send pull requests to the `GitHub repository`_ and `issue
tracker`_.

.. _GitHub repository: https://github.com/vicalloy/django-lbutils/
.. _issue tracker: https://github.com/vicalloy/django-lbutils/issues
